.. :changelog:

Release History
---------------
v0.1.2 (2018-07-03)

+++++++++++++++++++

**Bugfixes**

- Add multi-system support


**Features**

- Add ci

**Improvements**

- change Rmd160 to use haslib


v0.0.4 (2018-06-15)

+++++++++++++++++++

**Bugfixes**

- Fixed bug what can't find so file in github clone


**Features**

- add `get_accounts`(get_key_accounts) `get_currency_balance` RPC API

**Improvements**

- add Chain call multiple actions
